<?php
/*
	Plugin Name: Bulk menu creator
	Plugin URI: https://kubiq.sk
	Description: Create multiple menu items at once
	Version: 2.0
	Author: KubiQ
	Author URI: https://kubiq.sk
	Text Domain: bulk_menu
	Domain Path: /languages
*/

class bulk_menu{
	public function __construct(){
		add_action( 'plugins_loaded', array( $this, 'plugins_loaded' ) );
		add_action( 'admin_init', array( $this, 'admin_init' ) );
	}

	function activate(){
		global $wpdb;
		$hiddens = $wpdb->get_results("SELECT user_id, meta_value FROM {$wpdb->usermeta} WHERE meta_key = 'metaboxhidden_nav-menus'");
		foreach( $hiddens as $hidden ){
			if( strpos( $hidden->meta_value, "bulk_menu_creator" ) !== false ){
				$hidden_menus = maybe_unserialize( $hidden->meta_value );
				$key = array_search( "bulk_menu_creator", $hidden_menus );
				unset( $hidden_menus[ $key ] );
				update_user_option( $hidden->user_id, "metaboxhidden_nav-menus", $hidden_menus, true );
			}
		}
	}

	function plugins_loaded(){
		load_plugin_textdomain( 'bulk_menu', FALSE, basename( dirname( __FILE__ ) ) . '/languages/' );
	}
	
	public function admin_init(){
		add_action( 'admin_enqueue_scripts', array( $this, 'admin_enqueue_scripts' ) );
		add_meta_box( 'bulk_menu_creator', __( 'Bulk menu', 'bulk_menu' ), array( $this, 'bulk_menu_box' ), 'nav-menus', 'side', 'high' );
	}
	
	public function bulk_menu_box(){
		global $_nav_menu_placeholder;
		$_nav_menu_placeholder = 0 > $_nav_menu_placeholder ? $_nav_menu_placeholder - 1 : -1; ?>
		<div id="bulk_menu_fields" class="posttypediv">
			<label>
				<?php _e( 'Menu items labels', 'bulk_menu' ) ?><br>
				<textarea id="bulk-menu-labels" style="width:100%;min-height:75px;margin-bottom:10px"></textarea>
			</label>
			<label>
				<?php _e( 'Menu items URLs', 'bulk_menu' ) ?><br>
				<textarea id="bulk-menu-urls" style="width:100%;min-height:75px;margin-bottom:10px"></textarea>
			</label>
			<button type="button" class="button-secondary right" id="process_bulk_menu_fields"><?php _e( 'Generate menu items', 'bulk_menu' ) ?></button>
			<span class="spinner"></span>
			<div style="display:none">
				<div class="tabs-panel tabs-panel-active">
					<ul class="categorychecklist form-no-clear">
						<li>
							<input type="checkbox" class="menu-item-checkbox" name="menu-item[<?php echo $_nav_menu_placeholder ?>][menu-item-object-id]" value="-1" checked="checked">
							<input type="text" class="menu-item-type" name="menu-item[<?php echo $_nav_menu_placeholder ?>][menu-item-type]" value="custom">
							<input type="text" class="menu-item-title" name="menu-item[<?php echo $_nav_menu_placeholder ?>][menu-item-title]" value="TEST">
							<input type="text" class="menu-item-url" name="menu-item[<?php echo $_nav_menu_placeholder ?>][menu-item-url]" value="#test">
						</li>
					</ul>
				</div>
				<p class="button-controls wp-clearfix">
					<span class="add-to-menu">
						<input type="submit" class="button-secondary submit-add-to-menu right" value="<?php _e( 'Generate menu items', 'bulk_menu' ) ?>" name="add-post-type-menu-item" id="submit-bulk_menu_fields">
						<span class="spinner"></span>
					</span>
				</p>
			</div>
		</div><?php
	}
	
	public function admin_enqueue_scripts(){
		if( get_current_screen()->base != 'nav-menus' ) return;
		wp_enqueue_script( 'bulk_menu_js', plugins_url( '/js/nav-menu.min.js', __FILE__ ), array('jquery'), 1 );
	}
}

$bulk_menu_var = new bulk_menu();
register_activation_hook( __FILE__, array( $bulk_menu_var, 'activate' ) );